@@ -2,7 +2,7 @@ package Catmandu::Cmd::import;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2023';
+our $VERSION = '1.2024';
 
 use parent 'Catmandu::Cmd';
 use Catmandu;
@@ -21,6 +21,11 @@ sub command_opt_spec {
     );
 }
 
+sub validate_args {
+    my ($self, $opt, $args) = @_;
+    return;
+}
+
 sub command {
     my ($self, $opts, $args) = @_;
 
